@@ -1,10 +1,10 @@
 #' Extract the Design of a linear mixed model
-#' 
+#'
 #' These functions extract various elements of the design of a fitted
 #' \code{lme}-, \code{mer} or \code{lmerMod}-Object.  They are called by
 #' \code{exactRLRT} and \code{exactLRT}.
-#' 
-#' 
+#'
+#'
 #' @aliases extract.lmerModDesign extract.lmeDesign
 #' @param m a fitted \code{lme}- or \code{merMod}-Object
 #' @return a a list with components
@@ -22,23 +22,22 @@
 #' Many thanks to Andrzej Galecki and Tomasz Burzykowski for bug fixes.
 #' @keywords utilities
 #' @examples
-#' 
+#'
 #' library(nlme)
-#' design <- extract.lmeDesign(lme(distance ~ age + Sex, data = Orthodont, 
+#' design <- extract.lmeDesign(lme(distance ~ age + Sex, data = Orthodont,
 #'                              random = ~ 1))
 #' str(design)
-#' 
+#'
 #' @export extract.lmeDesign
-#' @importFrom stats complete.cases formula model.frame model.matrix 
-#' @importFrom nlme getGroups 
+#' @importFrom stats complete.cases formula model.frame model.matrix
+#' @importFrom nlme getGroups
 #' @importFrom mgcv tensor.prod.model.matrix
-extract.lmeDesign <- function(m)
-{
+extract.lmeDesign <- function(m) {
   start.level = 1
-  
-  data <- if(any(!complete.cases(m$data))){
-    warning("Removing incomplete cases from supplied data.") 
-    m$data[complete.cases(m$data),]
+
+  data <- if (any(!complete.cases(m$data))) {
+    warning("Removing incomplete cases from supplied data.")
+    m$data[complete.cases(m$data), ]
   } else m$data
   grps <- getGroups(m)
   n <- length(grps)
@@ -51,13 +50,16 @@ extract.lmeDesign <- function(m)
   Z <- matrix(0, n, 0)
   if (start.level <= n.levels) {
     for (i in 1:(n.levels - start.level + 1)) {
-      if(length(levels(m$groups[[n.levels-i+1]])) != 1) {
-        X[[1]] <- model.matrix(~m$groups[[n.levels - i +  1]] - 1, 
-          contrasts.arg = list(`~m$groups[[n.levels - i +  1]]` = "contr.treatment"))
+      if (length(levels(m$groups[[n.levels - i + 1]])) != 1) {
+        grps <- m$groups[[n.levels - i + 1]]
+        X[[1]] <- model.matrix(
+          ~ grps - 1,
+          contrasts.arg = list(grps = "contr.treatment")
+        )
+      } else {
+        X[[1]] <- matrix(1, n, 1)
       }
-      else X[[1]]<-matrix(1, n, 1)
-      X[[2]] <- as.matrix(Zt[, i.col:(i.col + grp.dims[i] -
-          1)])
+      X[[2]] <- as.matrix(Zt[, i.col:(i.col + grp.dims[i] - 1)])
       i.col <- i.col + grp.dims[i]
       Z <- cbind(tensor.prod.model.matrix(X), Z)
     }
@@ -67,27 +69,27 @@ extract.lmeDesign <- function(m)
       k <- n.levels - i + 1
       for (j in 1:m$dims$ngrps[i]) {
         stop <- start + ncol(cov[[k]]) - 1
-        Vr[ncol(Z)+1-(stop:start),ncol(Z)+1-(stop:start)] <- cov[[k]]
+        Vr[ncol(Z) + 1 - (stop:start), ncol(Z) + 1 - (stop:start)] <- cov[[k]]
         start <- stop + 1
       }
     }
   }
-  X <- if(class(m$call$fixed) == "name" &&  !is.null(m$data$X)){
+  X <- if (inherits(m$call$fixed, "name") && !is.null(m$data$X)) {
     m$data$X
-  } else 	{
+  } else {
     model.matrix(formula(eval(m$call$fixed)), data)
   }
-  y <- as.vector(matrix(m$residuals, ncol=NCOL(m$residuals))[,NCOL(m$residuals)] + 
-      matrix(m$fitted, ncol=NCOL(m$fitted))[,NCOL(m$fitted)])
+  y <- as.vector(
+    matrix(m$residuals, ncol = NCOL(m$residuals))[, NCOL(m$residuals)] +
+      matrix(m$fitted, ncol = NCOL(m$fitted))[, NCOL(m$fitted)]
+  )
   return(list(
-    Vr=Vr, #Cov(RanEf)/Var(Error)
-    X=X,
-    Z=Z,
-    sigmasq=m$sigma^2,
-    lambda=unique(diag(Vr)),
-    y=y,
-    k=n.levels
-  )
-  )
+    Vr = Vr, #Cov(RanEf)/Var(Error)
+    X = X,
+    Z = Z,
+    sigmasq = m$sigma^2,
+    lambda = unique(diag(Vr)),
+    y = y,
+    k = n.levels
+  ))
 }
-
